@@ -6,7 +6,7 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -58,6 +58,26 @@ class EmitCInlines : EmitCBaseVisitor {
         v3Global.needHeavy(true);
         iterateChildren(nodep);
     }
+    virtual void visit(AstAtoN* nodep) {
+        v3Global.needHeavy(true);
+        iterateChildren(nodep);
+    }
+    virtual void visit(AstPutcN* nodep) {
+        v3Global.needHeavy(true);
+        iterateChildren(nodep);
+    }
+    virtual void visit(AstGetcN* nodep) {
+        v3Global.needHeavy(true);
+        iterateChildren(nodep);
+    }
+    virtual void visit(AstSubstrN* nodep) {
+        v3Global.needHeavy(true);
+        iterateChildren(nodep);
+    }
+    virtual void visit(AstCompareNN* nodep) {
+        v3Global.needHeavy(true);
+        iterateChildren(nodep);
+    }
 
     // Default
     virtual void visit(AstNode* nodep) {
@@ -81,8 +101,7 @@ void EmitCInlines::emitInt() {
     m_ofp = &hf;
 
     ofp()->putsHeader();
-    puts("#ifndef _"+topClassName()+"__Inlines_H_\n");
-    puts("#define _"+topClassName()+"__Inlines_H_\n");
+    ofp()->putsGuard();
     puts("\n");
 
     puts("#include \"verilated.h\"\n");
@@ -92,7 +111,7 @@ void EmitCInlines::emitInt() {
     // Placeholder - v3Global.needHInlines(true) currently not used
 
     puts("//======================\n\n");
-    puts("#endif  // guard\n");
+    ofp()->putsEndGuard();
 }
 
 //######################################################################
