@@ -6,7 +6,7 @@
 //
 //*************************************************************************
 //
-// Copyright 2004-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2004-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -55,15 +55,14 @@ private:
     VL_DEBUG_FUNC;  // Declare debug()
 
     int longOrQuadWidth(AstNode* nodep) {
-        // Return 32 or 64...
-        return (nodep->width()+(VL_WORDSIZE-1)) & ~(VL_WORDSIZE-1);
+        return (nodep->width() + (VL_EDATASIZE - 1)) & ~(VL_EDATASIZE - 1);
     }
     V3Number notWideMask(AstNode* nodep) {
-        return V3Number(nodep, VL_WORDSIZE, ~VL_MASK_I(nodep->widthMin()));
+        return V3Number(nodep, VL_EDATASIZE, ~VL_MASK_E(nodep->widthMin()));
     }
     V3Number wordMask(AstNode* nodep) {
         if (nodep->isWide()) {
-            return V3Number(nodep, VL_WORDSIZE, VL_MASK_I(nodep->widthMin()));
+            return V3Number(nodep, VL_EDATASIZE, VL_MASK_E(nodep->widthMin()));
         } else {
             V3Number mask (nodep, longOrQuadWidth(nodep));
             mask.setMask(nodep->widthMin());
@@ -118,13 +117,13 @@ private:
             return new AstWordSel(nodep->fileline(),
                                   nodep->cloneTree(true),
                                   new AstConst(nodep->fileline(), word));
-        } else if (nodep->isQuad() && word==0) {
+        } else if (nodep->isQuad() && word == 0) {
             AstNode* quadfromp = nodep->cloneTree(true);
             quadfromp->dtypeSetBitUnsized(VL_QUADSIZE, quadfromp->widthMin(),
                                           AstNumeric::UNSIGNED);
             return new AstCCast(nodep->fileline(),
                                 quadfromp,
-                                VL_WORDSIZE);
+                                VL_EDATASIZE);
         } else if (nodep->isQuad() && word==1) {
             AstNode* quadfromp = nodep->cloneTree(true);
             quadfromp->dtypeSetBitUnsized(VL_QUADSIZE, quadfromp->widthMin(),
@@ -132,10 +131,10 @@ private:
             return new AstCCast(nodep->fileline(),
                                 new AstShiftR(nodep->fileline(),
                                               quadfromp,
-                                              new AstConst(nodep->fileline(), VL_WORDSIZE),
-                                              VL_WORDSIZE),
-                                VL_WORDSIZE);
-        } else if (!nodep->isWide() && !nodep->isQuad() && word==0) {
+                                              new AstConst(nodep->fileline(), VL_EDATASIZE),
+                                              VL_EDATASIZE),
+                                VL_EDATASIZE);
+        } else if (!nodep->isWide() && !nodep->isQuad() && word == 0) {
             return nodep->cloneTree(true);
         } else {  // Out of bounds
             return new AstConst(nodep->fileline(), 0);
@@ -148,25 +147,25 @@ private:
         AstNode* newp;
         // Negative word numbers requested for lhs when it's "before" what we want.
         // We get a 0 then.
-        int othword = word - shift/VL_WORDSIZE;
+        int othword = word - shift / VL_EDATASIZE;
         AstNode* llowp = newAstWordSelClone(lhsp, othword);
-        if (int loffset = VL_BITBIT_I(shift)) {
+        if (int loffset = VL_BITBIT_E(shift)) {
             AstNode* lhip = newAstWordSelClone(lhsp, othword-1);
-            int nbitsonright = VL_WORDSIZE-loffset;  // bits that end up in lword
+            int nbitsonright = VL_EDATASIZE - loffset;  // bits that end up in lword
             newp = new AstOr
                 (fl,
                  new AstAnd(fl,
-                            new AstConst(fl, VL_MASK_I(loffset)),
+                            new AstConst(fl, AstConst::SizedEData(), VL_MASK_E(loffset)),
                             new AstShiftR(fl,
                                           lhip,
                                           new AstConst(fl, nbitsonright),
-                                          VL_WORDSIZE)),
+                                          VL_EDATASIZE)),
                  new AstAnd(fl,
-                            new AstConst(fl, ~VL_MASK_I(loffset)),
+                            new AstConst(fl, AstConst::SizedEData(), ~VL_MASK_E(loffset)),
                             new AstShiftL(fl,
                                           llowp,
                                           new AstConst(fl, loffset),
-                                          VL_WORDSIZE)));
+                                          VL_EDATASIZE)));
         } else {
             newp = llowp;
         }
@@ -177,12 +176,12 @@ private:
         // Return equation to get the VL_BITWORD of a constant or non-constant
         if (VN_IS(lsbp, Const)) {
             return new AstConst(lsbp->fileline(),
-                                wordAdder + VL_BITWORD_I(VN_CAST(lsbp, Const)->toUInt()));
+                                wordAdder + VL_BITWORD_E(VN_CAST(lsbp, Const)->toUInt()));
         } else {
             AstNode* shiftp = new AstShiftR(lsbp->fileline(),
                                             lsbp->cloneTree(true),
-                                            new AstConst(lsbp->fileline(), VL_WORDSIZE_LOG2),
-                                            VL_WORDSIZE);
+                                            new AstConst(lsbp->fileline(), VL_EDATASIZE_LOG2),
+                                            VL_EDATASIZE);
             if (wordAdder != 0) {
                 shiftp = new AstAdd(lsbp->fileline(),
                                     // This is indexing a arraysel, so a 32 bit constant is fine
@@ -208,10 +207,10 @@ private:
         // Return equation to get the VL_BITBIT of a constant or non-constant
         if (VN_IS(lsbp, Const)) {
             return new AstConst(lsbp->fileline(),
-                                VL_BITBIT_I(VN_CAST(lsbp, Const)->toUInt()));
+                                VL_BITBIT_E(VN_CAST(lsbp, Const)->toUInt()));
         } else {
             return new AstAnd(lsbp->fileline(),
-                              new AstConst(lsbp->fileline(), VL_WORDSIZE-1),
+                              new AstConst(lsbp->fileline(), VL_EDATASIZE - 1),
                               dropCondBound(lsbp)->cloneTree(true));
         }
     }
@@ -226,8 +225,8 @@ private:
         }
         for (int w=0; w<nodep->widthWords(); w++) {
             addWordAssign(nodep, w, new AstConst(nodep->fileline(),
-                                                 AstConst::WidthedValue(),
-                                                 VL_WORDSIZE, rhsp->num().dataWord(w)));
+                                                 AstConst::SizedEData(),
+                                                 rhsp->num().edataWord(w)));
         }
         return true;
     }
@@ -339,7 +338,7 @@ private:
             addWordAssign(nodep, w, newAstWordSelClone(rhsp->lhsp(), w));
         }
         for (; w<nodep->widthWords(); w++) {
-            addWordAssign(nodep, w, new AstConst(rhsp->fileline(), 0));
+            addWordAssign(nodep, w, new AstConst(rhsp->fileline(), AstConst::SizedEData(), 0));
         }
         return true;
     }
@@ -387,7 +386,7 @@ private:
                 // nbitsfromlow <= (lsb==0) ? 64-bitbit(lsb) : 32-bitbit(lsb)
                 AstNode* midshiftp = new AstSub(nodep->lsbp()->fileline(),
                                                 new AstConst(nodep->lsbp()->fileline(),
-                                                             VL_WORDSIZE),
+                                                             VL_EDATASIZE),
                                                 newSelBitBit(nodep->lsbp()));
                 if (nodep->isQuad()) {
                     midshiftp =
@@ -395,7 +394,7 @@ private:
                                     new AstEq(nodep->fileline(),
                                               new AstConst(nodep->fileline(), 0),
                                               newSelBitBit(nodep->lsbp())),
-                                    new AstConst(nodep->lsbp()->fileline(), VL_WORDSIZE),
+                                    new AstConst(nodep->lsbp()->fileline(), VL_EDATASIZE),
                                     midshiftp);
                 }
                 AstNode* midmayp = new AstShiftL(nodep->fileline(),
@@ -415,7 +414,7 @@ private:
             }
             // If > 32 bits, we might be crossing the second word boundary
             AstNode* hip = NULL;
-            if (nodep->widthConst() > VL_WORDSIZE) {
+            if (nodep->widthConst() > VL_EDATASIZE) {
                 AstNode* hiwordp =  // SEL(from,[2+wordnum])
                     new AstWordSel(nodep->fromp()->fileline(),
                                    nodep->fromp()->cloneTree(true),
@@ -468,11 +467,11 @@ private:
 
     bool expandWide(AstNodeAssign* nodep, AstSel* rhsp) {
         UASSERT_OBJ(nodep->widthMin() == rhsp->widthConst(), nodep, "Width mismatch");
-        if (VN_IS(rhsp->lsbp(), Const) && VL_BITBIT_I(rhsp->lsbConst())==0) {
+        if (VN_IS(rhsp->lsbp(), Const) && VL_BITBIT_E(rhsp->lsbConst()) == 0) {
             int lsb = rhsp->lsbConst();
             UINFO(8,"    Wordize ASSIGN(SEL,align) "<<nodep<<endl);
             for (int w=0; w<nodep->widthWords(); w++) {
-                addWordAssign(nodep, w, newAstWordSelClone(rhsp->fromp(), w + VL_BITWORD_I(lsb)));
+                addWordAssign(nodep, w, newAstWordSelClone(rhsp->fromp(), w + VL_BITWORD_E(lsb)));
             }
             return true;
         } else {
@@ -485,20 +484,21 @@ private:
                 AstNode* lowp = new AstShiftR(rhsp->fileline(),
                                               lowwordp,
                                               newSelBitBit(rhsp->lsbp()),
-                                              VL_WORDSIZE);
+                                              VL_EDATASIZE);
                 // Upper bits
-                V3Number zero (nodep, VL_WORDSIZE, 0);
+                V3Number zero (nodep, VL_EDATASIZE, 0);
                 AstNode* midwordp =  // SEL(from,[1+wordnum])
                     new AstWordSel(rhsp->fromp()->fileline(),
                                    rhsp->fromp()->cloneTree(true),
                                    newSelBitWord(rhsp->lsbp(), w+1));
                 AstNode* midshiftp = new AstSub(rhsp->lsbp()->fileline(),
-                                                new AstConst(rhsp->lsbp()->fileline(), VL_WORDSIZE),
+                                                new AstConst(rhsp->lsbp()->fileline(),
+                                                             VL_EDATASIZE),
                                                 newSelBitBit(rhsp->lsbp()));
                 AstNode* midmayp = new AstShiftL(rhsp->fileline(),
                                                  midwordp,
                                                  midshiftp,
-                                                 VL_WORDSIZE);
+                                                 VL_EDATASIZE);
                 AstNode* midp = new AstCond(rhsp->fileline(),
                                             new AstEq(rhsp->fileline(),
                                                       new AstConst(rhsp->fileline(), 0),
@@ -534,14 +534,15 @@ private:
             if (destwide) {
                 UINFO(8,"    ASSIGNSEL(const,wide) "<<nodep<<endl);
                 for (int w=0; w<destp->widthWords(); w++) {
-                    if (w>=VL_BITWORD_I(lsb) && w<=VL_BITWORD_I(msb)) {
+                    if (w >= VL_BITWORD_E(lsb) && w <= VL_BITWORD_E(msb)) {
                         // else we would just be setting it to the same exact value
                         AstNode* oldvalp = newAstWordSelClone(destp, w);
                         fixCloneLvalue(oldvalp);
                         if (!ones) {
                             oldvalp = new AstAnd(lhsp->fileline(),
                                                  new AstConst(lhsp->fileline(),
-                                                              maskold.dataWord(w)),
+                                                              AstConst::SizedEData(),
+                                                              maskold.edataWord(w)),
                                                  oldvalp);
                         }
                         addWordAssign(nodep, w,
@@ -598,18 +599,18 @@ private:
                                      // That's ok as we'd just AND with a larger value,
                                      // but oldval would clip the upper bits to sanity
                                      newSelBitBit(lhsp->lsbp()),
-                                     VL_WORDSIZE)),
+                                     VL_EDATASIZE)),
                          oldvalp);
                 }
                 // Restrict the shift amount to 0-31, see bug804.
                 AstNode* shiftp = new AstAnd(nodep->fileline(), lhsp->lsbp()->cloneTree(true),
-                                             new AstConst(nodep->fileline(), VL_WORDSIZE-1));
+                                             new AstConst(nodep->fileline(), VL_EDATASIZE - 1));
                 AstNode* newp = new AstOr(lhsp->fileline(),
                                           oldvalp,
                                           new AstShiftL(lhsp->fileline(),
                                                         rhsp,
                                                         shiftp,
-                                                        VL_WORDSIZE));
+                                                        VL_EDATASIZE));
                 newp = new AstAssign(nodep->fileline(),
                                      new AstWordSel(nodep->fileline(),
                                                     destp,
@@ -762,7 +763,7 @@ private:
             AstNode* newp;
             if (lhswidth==1) {
                 newp = new AstNegate(nodep->fileline(), lhsp->cloneTree(true));
-                newp->dtypeSetLogicSized(VL_WORDSIZE,
+                newp->dtypeSetLogicSized(VL_EDATASIZE,
                                          AstNumeric::UNSIGNED);  // Replicate always unsigned
             } else {
                 newp = newAstWordSelClone(lhsp, w);
@@ -808,10 +809,12 @@ private:
             }
             if (VN_IS(nodep, Neq)) {
                 newp = new AstNeq(nodep->fileline(),
-                                  new AstConst(nodep->fileline(), 0), newp);
+                                  new AstConst(nodep->fileline(), AstConst::SizedEData(), 0),
+                                  newp);
             } else {
                 newp = new AstEq(nodep->fileline(),
-                                  new AstConst(nodep->fileline(), 0), newp);
+                                 new AstConst(nodep->fileline(), AstConst::SizedEData(), 0),
+                                 newp);
             }
             replaceWithDelete(nodep, newp); VL_DANGLING(nodep);
         }
@@ -831,7 +834,8 @@ private:
                 newp = (newp==NULL) ? eqp : (new AstOr(nodep->fileline(), newp, eqp));
             }
             newp = new AstNeq(nodep->fileline(),
-                              new AstConst(nodep->fileline(), 0), newp);
+                              new AstConst(nodep->fileline(), AstConst::SizedEData(), 0),
+                              newp);
             replaceWithDelete(nodep, newp); VL_DANGLING(nodep);
         } else {
             UINFO(8,"    REDOR->EQ "<<nodep<<endl);
@@ -864,7 +868,8 @@ private:
                 newp = (newp==NULL) ? eqp : (new AstAnd(nodep->fileline(), newp, eqp));
             }
             newp = new AstEq(nodep->fileline(),
-                             new AstConst(nodep->fileline(), ~0), newp);
+                             new AstConst(nodep->fileline(), AstConst::SizedEData(),
+                                          ~VL_MASK_E(0)), newp);
             replaceWithDelete(nodep, newp); VL_DANGLING(nodep);
         } else {
             UINFO(8,"    REDAND->EQ "<<nodep<<endl);
