@@ -6,7 +6,7 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -25,6 +25,7 @@
 #include "V3File.h"
 #include "V3Os.h"
 #include "V3PreShell.h"
+#include "V3String.h"
 #include "V3Ast.h"
 
 #include <cerrno>
@@ -52,6 +53,10 @@
 # include <sys/wait.h>
 #endif
 
+#if defined(_WIN32) || defined(__MINGW32__)
+# include <io.h>  // open, read, write, close
+#endif
+
 // If change this code, run a test with the below size set very small
 //#define INFILTER_IPC_BUFSIZ 16
 #define INFILTER_IPC_BUFSIZ (64*1024)  // For debug, try this as a small number
@@ -408,8 +413,7 @@ private:
                      || errno == EWOULDBLOCK
 #endif
                 ) {
-                // cppcheck-suppress obsoleteFunctionsusleep
-                checkFilter(false); usleep(1000); continue;
+                checkFilter(false); V3Os::u_sleep(1000); continue;
             } else { m_readEof = true; break; }
         }
         return out;
@@ -447,8 +451,7 @@ private:
                      || errno == EWOULDBLOCK
 #endif
                 ) {
-                // cppcheck-suppress obsoleteFunctionsusleep
-                checkFilter(false); usleep(1000); continue;
+                checkFilter(false); V3Os::u_sleep(1000); continue;
             }
             else break;
         }
@@ -942,6 +945,17 @@ void V3OutFile::putsForceIncs() {
     }
 }
 
+void V3OutCFile::putsGuard() {
+    UASSERT(!m_guard, "Already called putsGuard in emit file");
+    m_guard = true;
+    string var = VString::upcase(string("_") + V3Os::filenameNonDir(filename()) + "_");
+    for (string::iterator pos = var.begin(); pos != var.end(); ++pos) {
+        if (!isalnum(*pos)) *pos = '_';
+    }
+    puts("\n#ifndef " + var + "\n");
+    puts("#define " + var + "  // guard\n");
+}
+
 //######################################################################
 // VIdProtect
 
