@@ -6,7 +6,7 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -44,6 +44,10 @@
 
 #include "config_rev.h"
 
+#if defined(_WIN32) || defined(__MINGW32__)
+# include <io.h>  // open, close
+#endif
+
 //######################################################################
 // V3 Internal state
 
@@ -250,7 +254,7 @@ V3LangCode::V3LangCode(const char* textp) {
     // Return code for given string, or ERROR, which is a bad code
     for (int codei=V3LangCode::L_ERROR; codei<V3LangCode::_ENUM_END; ++codei) {
         V3LangCode code = V3LangCode(codei);
-        if (0==strcasecmp(textp, code.ascii())) {
+        if (0 == VL_STRCASECMP(textp, code.ascii())) {
             m_e = code; return;
         }
     }
@@ -727,6 +731,7 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             VOptionBool bflag;
             // Allow gnu -- switches
             if (sw[0]=='-' && sw[1]=='-') ++sw;
+            bool hadSwitchPart1 = true;
             if (0) {}
             // Single switches
             else if (!strcmp(sw, "-E"))                         { m_preprocOnly = true; }
@@ -799,6 +804,8 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if ( onoff (sw, "-Wpedantic", flag/*ref*/))         { m_pedantic = flag; }
             else if ( onoff (sw, "-x-initial-edge", flag/*ref*/))    { m_xInitialEdge = flag; }
             else if ( onoff (sw, "-xml-only", flag/*ref*/))          { m_xmlOnly = flag; }  // Undocumented, still experimental
+            else { hadSwitchPart1 = false; }
+            if (hadSwitchPart1) {}
             // Optimization
             else if (!strncmp (sw, "-O", 2)) {
                 for (const char* cp=sw+strlen("-O"); *cp; ++cp) {
@@ -1361,11 +1368,12 @@ void V3Options::parseOptsFile(FileLine* fl, const string& filename, bool rel) {
     string optdir = (rel ? V3Os::filenameDir(filename) : ".");
 
     // Convert to argv style arg list and parse them
-    char* argv [args.size()+1];
-    for (unsigned i=0; i<args.size(); ++i) {
-        argv[i] = const_cast<char*>(args[i].c_str());
+    std::vector<char*> argv; argv.reserve(args.size()+1);
+    for (std::vector<std::string>::const_iterator it = args.begin(); it != args.end(); ++it) {
+        argv.push_back(const_cast<char*>(it->c_str()));
     }
-    parseOptsList(fl, optdir, args.size(), argv);
+    argv.push_back(NULL); // argv is NULL-terminated
+    parseOptsList(fl, optdir, static_cast<int>(argv.size()-1), argv.data());
 }
 
 //======================================================================
@@ -1401,7 +1409,7 @@ void V3Options::showVersion(bool verbose) {
     if (!verbose) return;
 
     cout <<endl;
-    cout << "Copyright 2003-2019 by Wilson Snyder.  Verilator is free software; you can\n";
+    cout << "Copyright 2003-2020 by Wilson Snyder.  Verilator is free software; you can\n";
     cout << "redistribute it and/or modify the Verilator internals under the terms of\n";
     cout << "either the GNU Lesser General Public License Version 3 or the Perl Artistic\n";
     cout << "License Version 2.0.\n";
