@@ -6,7 +6,7 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -88,6 +88,14 @@ string VString::downcase(const string& str) {
     return out;
 }
 
+string VString::upcase(const string& str) {
+    string out = str;
+    for (string::iterator pos = out.begin(); pos != out.end(); ++pos) {
+        *pos = toupper(*pos);
+    }
+    return out;
+}
+
 string VString::quotePercent(const string& str) {
     string out;
     for (string::const_iterator pos = str.begin(); pos != str.end(); ++pos) {
