@@ -6,7 +6,7 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
+// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -252,6 +252,7 @@ public:
         m_callGraph.dumpDotFilePrefixed("task_call");
     }
     virtual ~TaskStateVisitor() {}
+    VL_UNCOPYABLE(TaskStateVisitor);
 };
 
 //######################################################################
@@ -630,10 +631,14 @@ private:
             return new AstCStmt(portp->fileline(), linesp);
         }
         // Use a AstCMath, as we want V3Clean to mask off bits that don't make sense.
-        int cwidth = VL_WORDSIZE;
-        if (portp->basicp()) cwidth = portp->basicp()->keyword().width();
-        if (portp->basicp()
-            && portp->basicp()->keyword().isBitLogic()) cwidth = VL_WORDSIZE*portp->widthWords();
+        int cwidth = VL_IDATASIZE;
+        if (portp->basicp()) {
+            if (portp->basicp()->keyword().isBitLogic()) {
+                cwidth = VL_EDATASIZE * portp->widthWords();
+            } else {
+                cwidth = portp->basicp()->keyword().width();
+            }
+        }
         AstNode* newp = new AstAssign(portp->fileline(),
                                       new AstVarRef(portp->fileline(), portvscp, true),
                                       new AstSel(portp->fileline(),
