@@ -12,7 +12,8 @@ scenarios(simulator => 1);
 top_filename("t/t_inst_tree.v");
 
 compile(
-    verilator_flags2 => ['+define+NOUSE_INLINE', '+define+USE_PUBLIC', '--stats', '--norelative-cfuncs'],
+    verilator_flags2 => ['+define+NOUSE_INLINE', '+define+USE_PUBLIC', '--stats', '--norelative-cfuncs',
+                         $Self->wno_unopthreads_for_few_cores()]
     );
 
 if ($Self->{vlt_all}) {
