@@ -47,9 +47,6 @@ using namespace std;
 
 unsigned int main_time = false;
 
-#define STRINGIFY(x) STRINGIFY2(x)
-#define STRINGIFY2(x) #x
-
 //======================================================================
 
 #define CHECK_RESULT_VH(got, exp) \
@@ -227,7 +224,7 @@ int main(int argc, char** argv, char** env) {
     VL_PRINTF("Enabling waves...\n");
     VerilatedVcdC* tfp = new VerilatedVcdC;
     topp->trace(tfp, 99);
-    tfp->open(STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
+    tfp->open(VL_STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
 #endif
 
     topp->eval();
